==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/GeneralIcons/InternetAlt2.md <==
# InternetAlt2


```text
aws-20210730/Resource/GeneralIcons/InternetAlt2
```

```text
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')
```



| Illustration | InternetAlt2 | InternetAlt2Card | InternetAlt2Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/GeneralIcons/InternetAlt2.png) | ![illustration for InternetAlt2](../../../aws-20210730/Resource/GeneralIcons/InternetAlt2.Local.png) | ![illustration for InternetAlt2Card](../../../aws-20210730/Resource/GeneralIcons/InternetAlt2Card.Local.png) | ![illustration for InternetAlt2Group](../../../aws-20210730/Resource/GeneralIcons/InternetAlt2Group.Local.png) |




## InternetAlt2

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2('InternetAlt2', 'Internet Alt2', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2('InternetAlt2', 'Internet Alt2', 'an optional tech label')
@enduml
```

## InternetAlt2Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2Card
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2Card('InternetAlt2Card', 'Internet Alt2 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2Card
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2Card('InternetAlt2Card', 'Internet Alt2 Card', 'an optional description')
@enduml
```

## InternetAlt2Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2Group
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2Group('InternetAlt2Group', 'Internet Alt2 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2Group
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2Group('InternetAlt2Group', 'Internet Alt2 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/GeneralIcons/InternetAlt2.md <==
# InternetAlt2


```text
aws-20210730/Resource/GeneralIcons/InternetAlt2
```

```text
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')
```



| Illustration | InternetAlt2 | InternetAlt2Card | InternetAlt2Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/GeneralIcons/InternetAlt2.png) | ![illustration for InternetAlt2](../../../aws-20210730/Resource/GeneralIcons/InternetAlt2.Local.png) | ![illustration for InternetAlt2Card](../../../aws-20210730/Resource/GeneralIcons/InternetAlt2Card.Local.png) | ![illustration for InternetAlt2Group](../../../aws-20210730/Resource/GeneralIcons/InternetAlt2Group.Local.png) |




## InternetAlt2

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2('InternetAlt2', 'Internet Alt2', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2('InternetAlt2', 'Internet Alt2', 'an optional tech label')
@enduml
```

## InternetAlt2Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2Card
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2Card('InternetAlt2Card', 'Internet Alt2 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2Card
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2Card('InternetAlt2Card', 'Internet Alt2 Card', 'an optional description')
@enduml
```

## InternetAlt2Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2Group
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2Group('InternetAlt2Group', 'Internet Alt2 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element InternetAlt2Group
include('aws-20210730/Resource/GeneralIcons/InternetAlt2')

' renders the element
InternetAlt2Group('InternetAlt2Group', 'Internet Alt2 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
